window.Gleam.initSearch([{"doc":"ratioed","title":"ratioed","content":"# ratioed\n\n[![Package Version](https://img.shields.io/hexpm/v/ratioed)](https://hex.pm/packages/ratioed)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/ratioed/)\n\nA Rational Number library for the Gleam programming language.\n\n## Quick start\n\nThe example below converts the floats 3/4 and 2/3 into rationals and multiplies them, giving a result of 1/2.\n\n```gleam\nimport gleam/io\nimport ratioed as r\n\npub fn main() {\n  let a = r.from_f(3.0 /. 4.0)\n  let b = r.from_f(2.0 /. 3.0)\n  r.mul(a, b)\n  |&gt; r.to_string\n  |&gt; io.println\n  // prints 1/2\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add ratioed\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/ratioed&gt;.\n","url":"index.html"},{"doc":"ratioed","title":"Ratio","content":"pub opaque type Ratio\n Ratio represents a rational number, i.e. one that can be represented as a fraction of two integers\n\nSynonyms:\nratioed.Ratio\nratioed Ratio","url":"ratioed.html#Ratio"},{"doc":"ratioed","title":"add","content":"pub fn add(a: Ratio, b: Ratio) -&gt; Ratio\n Add two rationals\nSynonyms:\nratioed.add\nratioed add","url":"ratioed.html#add"},{"doc":"ratioed","title":"compare","content":"pub fn compare(a: Ratio, b: Ratio) -&gt; Order\n Compare two rationals\nSynonyms:\nratioed.compare\nratioed compare","url":"ratioed.html#compare"},{"doc":"ratioed","title":"div","content":"pub fn div(a: Ratio, b: Ratio) -&gt; Ratio\n Divide one rational by another, division by 0 will return 0.\nSynonyms:\nratioed.div\nratioed div","url":"ratioed.html#div"},{"doc":"ratioed","title":"from_f","content":"pub fn from_f(f: Float) -&gt; Ratio\n Create a rational from a float with maximum error of 2^-51\nSynonyms:\nratioed.from_f\nratioed from_f","url":"ratioed.html#from_f"},{"doc":"ratioed","title":"from_f_epsilon","content":"pub fn from_f_epsilon(f: Float, e: Float) -&gt; Ratio\n Create a rational from a float with a given maximum error\nSynonyms:\nratioed.from_f_epsilon\nratioed from_f_epsilon","url":"ratioed.html#from_f_epsilon"},{"doc":"ratioed","title":"from_i","content":"pub fn from_i(n: Int) -&gt; Ratio\n Create a ratio from an integer\nSynonyms:\nratioed.from_i\nratioed from_i","url":"ratioed.html#from_i"},{"doc":"ratioed","title":"from_i2","content":"pub fn from_i2(numerator n: Int, denominator d: Int) -&gt; Ratio\n Create a rational given an integer numerator and denominator\nSynonyms:\nratioed.from_i2\nratioed from_i2","url":"ratioed.html#from_i2"},{"doc":"ratioed","title":"mul","content":"pub fn mul(a: Ratio, b: Ratio) -&gt; Ratio\n Multiply two rationals\nSynonyms:\nratioed.mul\nratioed mul","url":"ratioed.html#mul"},{"doc":"ratioed","title":"sub","content":"pub fn sub(a: Ratio, b: Ratio) -&gt; Ratio\n Subtract one rational from another\nSynonyms:\nratioed.sub\nratioed sub","url":"ratioed.html#sub"},{"doc":"ratioed","title":"to_f","content":"pub fn to_f(ratio: Ratio) -&gt; Float\n Convert a rational to a floating point number\nSynonyms:\nratioed.to_f\nratioed to_f","url":"ratioed.html#to_f"},{"doc":"ratioed","title":"to_i","content":"pub fn to_i(a: Ratio) -&gt; Int\n Convert a rational to an integer, truncating (round towards 0)\nSynonyms:\nratioed.to_i\nratioed to_i","url":"ratioed.html#to_i"},{"doc":"ratioed","title":"to_string","content":"pub fn to_string(ratio: Ratio) -&gt; String\n\nSynonyms:\nratioed.to_string\nratioed to_string","url":"ratioed.html#to_string"},{"doc":"ratioed","title":"ratioed","content":"","url":"ratioed.html"}]);